@@ -14,7 +14,7 @@
   Lesser General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
-  License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef KSMTP_SESSION_H
@@ -25,10 +25,7 @@
 
 #include <QObject>
 
-
-namespace KSmtp
-{
-
+namespace KSmtp {
 class SessionPrivate;
 class SessionThread;
 
@@ -164,7 +161,6 @@ private:
 
     SessionPrivate *const d;
 };
-
 }
 
 #endif // KSMTP_SESSION_H
